==> virtuoso-opensource-7.2.4.2.tar.gz: virtuoso-opensource-7.2.4.2/libsrc/Wi/turtle_p.h <==
/* A Bison parser, made by GNU Bison 2.7.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_TTLYY_TURTLE_P_H_INCLUDED
# define YY_TTLYY_TURTLE_P_H_INCLUDED
/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int ttlyydebug;
#endif

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     __TTL_PUNCT_BEGIN = 258,
     _CARET_WS = 259,
     _CARET_NOWS = 260,
     _CARET_CARET = 261,
     _COLON = 262,
     _COMMA = 263,
     _DOT_WS = 264,
     _LBRA = 265,
     _LBRA_TOP_TRIG = 266,
     _LPAR = 267,
     _LSQBRA = 268,
     _LSQBRA_RSQBRA = 269,
     _RBRA = 270,
     _RPAR = 271,
     _RSQBRA = 272,
     _SEMI = 273,
     _EQ = 274,
     _EQ_TOP_TRIG = 275,
     _EQ_GT = 276,
     _LT_EQ = 277,
     _BANG = 278,
     _AT_a_L = 279,
     _AT_base_L = 280,
     _AT_has_L = 281,
     _AT_is_L = 282,
     _AT_keywords_L = 283,
     _AT_of_L = 284,
     _AT_prefix_L = 285,
     _AT_this_L = 286,
     _MINUS_INF_L = 287,
     BASE_L = 288,
     INF_L = 289,
     NaN_L = 290,
     PREFIX_L = 291,
     false_L = 292,
     true_L = 293,
     __TTL_PUNCT_END = 294,
     __TTL_NONPUNCT_START = 295,
     TURTLE_INTEGER = 296,
     TURTLE_DECIMAL = 297,
     TURTLE_DOUBLE = 298,
     TURTLE_STRING = 299,
     KEYWORD = 300,
     LANGTAG = 301,
     QNAME = 302,
     QNAME_NS = 303,
     VARIABLE = 304,
     BLANK_NODE_LABEL_NQ = 305,
     BLANK_NODE_LABEL_TTL = 306,
     Q_IRI_REF = 307,
     _GARBAGE_BEFORE_DOT_WS = 308,
     TTL_RECOVERABLE_ERROR = 309,
     __TTL_NONPUNCT_END = 310
   };
#endif
/* Tokens.  */
#define __TTL_PUNCT_BEGIN 258
#define _CARET_WS 259
#define _CARET_NOWS 260
#define _CARET_CARET 261
#define _COLON 262
#define _COMMA 263
#define _DOT_WS 264
#define _LBRA 265
#define _LBRA_TOP_TRIG 266
#define _LPAR 267
#define _LSQBRA 268
#define _LSQBRA_RSQBRA 269
#define _RBRA 270
#define _RPAR 271
#define _RSQBRA 272
#define _SEMI 273
#define _EQ 274
#define _EQ_TOP_TRIG 275
#define _EQ_GT 276
#define _LT_EQ 277
#define _BANG 278
#define _AT_a_L 279
#define _AT_base_L 280
#define _AT_has_L 281
#define _AT_is_L 282
#define _AT_keywords_L 283
#define _AT_of_L 284
#define _AT_prefix_L 285
#define _AT_this_L 286
#define _MINUS_INF_L 287
#define BASE_L 288
#define INF_L 289
#define NaN_L 290
#define PREFIX_L 291
#define false_L 292
#define true_L 293
#define __TTL_PUNCT_END 294
#define __TTL_NONPUNCT_START 295
#define TURTLE_INTEGER 296
#define TURTLE_DECIMAL 297
#define TURTLE_DOUBLE 298
#define TURTLE_STRING 299
#define KEYWORD 300
#define LANGTAG 301
#define QNAME 302
#define QNAME_NS 303
#define VARIABLE 304
#define BLANK_NODE_LABEL_NQ 305
#define BLANK_NODE_LABEL_TTL 306
#define Q_IRI_REF 307
#define _GARBAGE_BEFORE_DOT_WS 308
#define TTL_RECOVERABLE_ERROR 309
#define __TTL_NONPUNCT_END 310



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{
/* Line 2058 of yacc.c  */
#line 73 "./turtle_p.y"

  caddr_t box;
  ptrlong token_type;
  void *nothing;
  ptrlong lexlineno;


/* Line 2058 of yacc.c  */
#line 175 "turtle_p.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif


#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int ttlyyparse (void *YYPARSE_PARAM);
#else
int ttlyyparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int ttlyyparse (ttlp_t * ttlp_arg, yyscan_t yyscanner);
#else
int ttlyyparse ();
#endif
#endif /* ! YYPARSE_PARAM */

#endif /* !YY_TTLYY_TURTLE_P_H_INCLUDED  */

==> virtuoso-opensource-7.2.5.tar.gz: virtuoso-opensource-7.2.5/libsrc/Wi/turtle_p.h <==
/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_TTLYY_TURTLE_P_H_INCLUDED
# define YY_TTLYY_TURTLE_P_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int ttlyydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    __TTL_PUNCT_BEGIN = 258,
    _CARET_WS = 259,
    _CARET_NOWS = 260,
    _CARET_CARET = 261,
    _COLON = 262,
    _COMMA = 263,
    _DOT_WS = 264,
    _LBRA = 265,
    _LBRA_TOP_TRIG = 266,
    _LPAR = 267,
    _LSQBRA = 268,
    _LSQBRA_RSQBRA = 269,
    _RBRA = 270,
    _RPAR = 271,
    _RSQBRA = 272,
    _SEMI = 273,
    _EQ = 274,
    _EQ_TOP_TRIG = 275,
    _EQ_GT = 276,
    _LT_EQ = 277,
    _BANG = 278,
    _AT_a_L = 279,
    _AT_base_L = 280,
    _AT_has_L = 281,
    _AT_is_L = 282,
    _AT_keywords_L = 283,
    _AT_of_L = 284,
    _AT_prefix_L = 285,
    _AT_this_L = 286,
    _MINUS_INF_L = 287,
    BASE_L = 288,
    INF_L = 289,
    NaN_L = 290,
    PREFIX_L = 291,
    false_L = 292,
    true_L = 293,
    __TTL_PUNCT_END = 294,
    __TTL_NONPUNCT_START = 295,
    TURTLE_INTEGER = 296,
    TURTLE_DECIMAL = 297,
    TURTLE_DOUBLE = 298,
    TURTLE_STRING = 299,
    KEYWORD = 300,
    LANGTAG = 301,
    QNAME = 302,
    QNAME_NS = 303,
    VARIABLE = 304,
    BLANK_NODE_LABEL_NQ = 305,
    BLANK_NODE_LABEL_TTL = 306,
    Q_IRI_REF = 307,
    _GARBAGE_BEFORE_DOT_WS = 308,
    TTL_RECOVERABLE_ERROR = 309,
    __TTL_NONPUNCT_END = 310
  };
#endif
/* Tokens.  */
#define __TTL_PUNCT_BEGIN 258
#define _CARET_WS 259
#define _CARET_NOWS 260
#define _CARET_CARET 261
#define _COLON 262
#define _COMMA 263
#define _DOT_WS 264
#define _LBRA 265
#define _LBRA_TOP_TRIG 266
#define _LPAR 267
#define _LSQBRA 268
#define _LSQBRA_RSQBRA 269
#define _RBRA 270
#define _RPAR 271
#define _RSQBRA 272
#define _SEMI 273
#define _EQ 274
#define _EQ_TOP_TRIG 275
#define _EQ_GT 276
#define _LT_EQ 277
#define _BANG 278
#define _AT_a_L 279
#define _AT_base_L 280
#define _AT_has_L 281
#define _AT_is_L 282
#define _AT_keywords_L 283
#define _AT_of_L 284
#define _AT_prefix_L 285
#define _AT_this_L 286
#define _MINUS_INF_L 287
#define BASE_L 288
#define INF_L 289
#define NaN_L 290
#define PREFIX_L 291
#define false_L 292
#define true_L 293
#define __TTL_PUNCT_END 294
#define __TTL_NONPUNCT_START 295
#define TURTLE_INTEGER 296
#define TURTLE_DECIMAL 297
#define TURTLE_DOUBLE 298
#define TURTLE_STRING 299
#define KEYWORD 300
#define LANGTAG 301
#define QNAME 302
#define QNAME_NS 303
#define VARIABLE 304
#define BLANK_NODE_LABEL_NQ 305
#define BLANK_NODE_LABEL_TTL 306
#define Q_IRI_REF 307
#define _GARBAGE_BEFORE_DOT_WS 308
#define TTL_RECOVERABLE_ERROR 309
#define __TTL_NONPUNCT_END 310

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED

union YYSTYPE
{
#line 73 "./turtle_p.y" /* yacc.c:1909  */

  caddr_t box;
  ptrlong token_type;
  void *nothing;
  ptrlong lexlineno;

#line 171 "turtle_p.h" /* yacc.c:1909  */
};

typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif



int ttlyyparse (ttlp_t * ttlp_arg, yyscan_t yyscanner);

#endif /* !YY_TTLYY_TURTLE_P_H_INCLUDED  */
